<?php

wpj_display_recaptcha_field( 'default_login' );

wpj_display_2fa_field();

if (
	( wpj_get_option( 'wpjobster_login_page_id' ) && wpj_page_content_type( wpj_get_option( 'wpjobster_login_page_id' ) ) != 'page_builder' )
	|| $GLOBALS['pagenow'] === 'wp-login.php'
) { ?>

	<div class="login-outer-wrapper">

		<div class="mt10">

			<?php wpj_display_keep_logged_in_field();

			wpj_display_forgot_password_field(); ?>

			<div class="ui hidden divider"></div>

			<?php wpj_display_or_field();

			do_action( 'wordpress_social_login' );

			wpj_display_already_field( 'login' ); ?>

		</div>

	</div>

<?php }